# helloengland

## Install

### From wheel

```bash
pip install 
```

### From source

```bash
python3 -m pip install flit
python3 -m flit build
```

## Publish

### Publish sdist

```bash
python3 -m flit publish
```
